@@ -87,8 +87,10 @@ bool arch_Gzip::ContainsMod(const string& aFileName)
 	string lCommand = "gunzip -l \"" + aFileName + '\"';   //get info
 	FILE *f = popen(lCommand.c_str(),"r");
 	
-	if (f <= 0)
+	if (f <= 0) {
+		pclose(f);
 		return false;
+	}
 	
 	char line[300];
 	fgets(line, 80, f);   // ignore a line.
