@@ -147,7 +147,7 @@ bool arch_Rar::ContainsMod(const string& aFileName)
 	while (num--)
 		fgets(lBuffer, 90, f); //ignore a line.
 
-		bool eof = false;
+	bool eof = false;
 	while(!eof)
 	{
 		if(fgets(lBuffer, 350, f) || f <= 0)
@@ -174,9 +174,12 @@ bool arch_Rar::ContainsMod(const string& aFileName)
 		
 		lName = lBuffer;
 		
-		if(IsOurFile(lName))
+		if(IsOurFile(lName)) {
+			pclose(f);
 			return true;
+		}
 	}
-	
+
+	pclose(f);	
 	return false;
 }
