@@ -9,11 +9,11 @@
 #include <unistd.h>
 #include <math.h>
 
-#include"modplugxmms.h"
-#include"libmodplug/stdafx.h"
-#include"libmodplug/sndfile.h"
-#include"stddefs.h"
-#include"archive/open.h"
+#include "modplugxmms.h"
+#include <libmodplug/stdafx.h>
+#include <libmodplug/sndfile.h>
+#include "stddefs.h"
+#include "archive/open.h"
 
 // ModplugXMMS member functions ===============================
 
@@ -252,6 +252,8 @@ bool ModplugXMMS::CanPlayFile(const string& aFilename)
 		return true;
 	if (lExt == ".itgz")
 		return true;
+	if (lExt == ".dmf")
+		return true;
 	
 	if (lExt == ".zip")
 		return ContainsMod(aFilename);
@@ -297,13 +299,26 @@ void ModplugXMMS::PlayLoop()
 			if(mModProps.mBits == 16)
 			{
 				uint n = mBufSize >> 1;
-				for(uint i = 0; i < n; i++)
+				for(uint i = 0; i < n; i++) {
+					short old = ((short*)mBuffer)[i];
 					((short*)mBuffer)[i] *= mPreampFactor;
+					// detect overflow and clip!
+					if ((old & 0x8000) != 
+					 (((short*)mBuffer)[i] & 0x8000))
+					  ((short*)mBuffer)[i] = old | 0x7FFF;
+						
+				}
 			}
 			else
 			{
-				for(uint i = 0; i < mBufSize; i++)
+				for(uint i = 0; i < mBufSize; i++) {
+					uchar old = ((uchar*)mBuffer)[i];
 					((uchar*)mBuffer)[i] *= mPreampFactor;
+					// detect overflow and clip!
+					if ((old & 0x80) != 
+					 (((uchar*)mBuffer)[i] & 0x80))
+					  ((uchar*)mBuffer)[i] = old | 0x7F;
+				}
 			}
 		}
 		
